==> clean_android_design-0.0.168.tar.gz: lib/src/navigator/locked_navigator_widget.dart <==
import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

class LockedNavigatorWidget extends StatefulWidget {
  final Widget child;

  const LockedNavigatorWidget({
    Key key,
    this.child,
  }) : super(key: key);

  @override
  _LockedNavigatorWidgetState createState() => _LockedNavigatorWidgetState();

  static _LockedNavigatorWidgetState _currentState;

  static void animate() {
    if (_currentState != null && _currentState.mounted) {
      _currentState._animationController.forward();
    }
  }

  static bool isLocked() {
    if (_currentState != null && _currentState.mounted) {
      return _currentState.isLocked;
    }
    return false;
  }

  static void setLocked(bool isLocked) {
    print("[LockedNavigatorWidget] setLocked: $isLocked - $_currentState");
    if (_currentState != null && _currentState.mounted) {
      _currentState.setLocked(isLocked);
    }
  }
}

class _LockedNavigatorWidgetState extends State<LockedNavigatorWidget>
    with SingleTickerProviderStateMixin {
  AnimationController _animationController;
  Animation<double> _opacityTween;

  int lockedCounter = 0;
  bool get isLocked => lockedCounter == 0;

  @override
  void initState() {
    super.initState();

    LockedNavigatorWidget._currentState = this;

    _animationController =
        AnimationController(vsync: this, duration: Duration(milliseconds: 300));
    _opacityTween =
        Tween<double>(begin: 0, end: 1).animate(_animationController);
  }

  void setLocked(bool isLocked) {
    print("[LockedNavigatorWidgetState] setLocked: $isLocked");
    setState(() {
      if (isLocked)
        lockedCounter++;
      else
        lockedCounter--;
    });
  }

  @override
  Widget build(BuildContext context) {
    return isLocked
        ? MouseRegion(
            onEnter: (event) => _animationController.forward(),
            onExit: (event) => _animationController.reverse(),
            child: Stack(
              children: [
                Row(
                  children: [
                    Expanded(
                      child: Column(
                        children: [
                          Expanded(child: Container()),
                        ],
                      ),
                    ),
                  ],
                ),
                widget.child,
                AnimatedBuilder(
                    animation: _opacityTween,
                    builder: (context, _) {
                      return Container(
                        width: _opacityTween.value == 0
                            ? 0
                            : MediaQuery.of(context).size.width,
                        height: _opacityTween.value == 0
                            ? 0
                            : MediaQuery.of(context).size.height,
                        color: CleanAndroidDesignDefaultColors.background
                            .withOpacity(0.7 * _opacityTween.value),
                        child: Center(
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.center,
                            mainAxisAlignment: MainAxisAlignment.center,
                            children: [
                              Icon(Icons.save,
                                  size: 33,
                                  color: Colors.grey[600]
                                      .withOpacity(_opacityTween.value)),
                              Container(height: 10),
                              Text("Bitte den aktuellen Bearbeitungsvorgang",
                                  style: TextStyles.defaultTextStyle().copyWith(
                                      color: Colors.grey[600]
                                          .withOpacity(_opacityTween.value))),
                              Text("abbrechen oder speichern!",
                                  style: TextStyles.defaultTextStyle().copyWith(
                                      color: Colors.grey[600]
                                          .withOpacity(_opacityTween.value))),
                              Container(height: 30),
                            ],
                          ),
                        ),
                      );
                    }),
              ],
            ),
          )
        : widget.child;
  }
}

==> clean_android_design-0.0.169.tar.gz: lib/src/navigator/locked_navigator_widget.dart <==
import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

class LockedNavigatorWidget extends StatefulWidget {
  final Widget child;

  const LockedNavigatorWidget({
    Key key,
    this.child,
  }) : super(key: key);

  @override
  _LockedNavigatorWidgetState createState() => _LockedNavigatorWidgetState();

  static _LockedNavigatorWidgetState _currentState;

  static void animate() {
    if (_currentState != null && _currentState.mounted) {
      _currentState._animationController.forward();
    }
  }

  static bool isLocked() {
    if (_currentState != null && _currentState.mounted) {
      return _currentState.isLocked;
    }
    return false;
  }

  static void setLocked(bool isLocked) {
    print("[LockedNavigatorWidget] setLocked: $isLocked - $_currentState");
    if (_currentState != null && _currentState.mounted) {
      _currentState.setLocked(isLocked);
    }
  }
}

class _LockedNavigatorWidgetState extends State<LockedNavigatorWidget>
    with SingleTickerProviderStateMixin {
  AnimationController _animationController;
  Animation<double> _opacityTween;

  int lockedCounter = 0;
  bool get isLocked => lockedCounter != 0;

  @override
  void initState() {
    super.initState();

    LockedNavigatorWidget._currentState = this;

    _animationController =
        AnimationController(vsync: this, duration: Duration(milliseconds: 300));
    _opacityTween =
        Tween<double>(begin: 0, end: 1).animate(_animationController);
  }

  void setLocked(bool isLocked) {
    print("[LockedNavigatorWidgetState] setLocked: $isLocked");
    setState(() {
      if (isLocked)
        lockedCounter++;
      else
        lockedCounter--;
    });
  }

  @override
  Widget build(BuildContext context) {
    return isLocked
        ? MouseRegion(
            onEnter: (event) => _animationController.forward(),
            onExit: (event) => _animationController.reverse(),
            child: Stack(
              children: [
                Row(
                  children: [
                    Expanded(
                      child: Column(
                        children: [
                          Expanded(child: Container()),
                        ],
                      ),
                    ),
                  ],
                ),
                widget.child,
                AnimatedBuilder(
                    animation: _opacityTween,
                    builder: (context, _) {
                      return Container(
                        width: _opacityTween.value == 0
                            ? 0
                            : MediaQuery.of(context).size.width,
                        height: _opacityTween.value == 0
                            ? 0
                            : MediaQuery.of(context).size.height,
                        color: CleanAndroidDesignDefaultColors.background
                            .withOpacity(0.7 * _opacityTween.value),
                        child: Center(
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.center,
                            mainAxisAlignment: MainAxisAlignment.center,
                            children: [
                              Icon(Icons.save,
                                  size: 33,
                                  color: Colors.grey[600]
                                      .withOpacity(_opacityTween.value)),
                              Container(height: 10),
                              Text("Bitte den aktuellen Bearbeitungsvorgang",
                                  style: TextStyles.defaultTextStyle().copyWith(
                                      color: Colors.grey[600]
                                          .withOpacity(_opacityTween.value))),
                              Text("abbrechen oder speichern!",
                                  style: TextStyles.defaultTextStyle().copyWith(
                                      color: Colors.grey[600]
                                          .withOpacity(_opacityTween.value))),
                              Container(height: 30),
                            ],
                          ),
                        ),
                      );
                    }),
              ],
            ),
          )
        : widget.child;
  }
}
